==> jena-3.7.0-source-release.zip: jena-3.7.0/jena-arq/src/test/java/org/apache/jena/sparql/function/user/TS_UserFunctions.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.sparql.function.user;

import org.apache.jena.sparql.function.user.UserDefinedFunctionDefinition ;
import org.junit.AfterClass ;
import org.junit.BeforeClass ;
import org.junit.runner.RunWith ;
import org.junit.runners.Suite ;
import org.junit.runners.Suite.SuiteClasses ;

@RunWith(Suite.class)
@SuiteClasses( {
    TestUserDefinedFunctionFactory.class,
    TestFunctionExpansion.class,
    TestFunctionNonExpansion.class,
    TestUserFunctionsInSparql.class
})
public class TS_UserFunctions {
	
	//Expected warnings off
	private static boolean bWarnOnUnusedVar;
	
	@BeforeClass
	public static void setup() {
		bWarnOnUnusedVar = UserDefinedFunctionDefinition.warnOnUnusedVariable;
		UserDefinedFunctionDefinition.warnOnUnusedVariable = false;
	}
	
	@AfterClass
	public static void teardown() {
		UserDefinedFunctionDefinition.warnOnUnusedVariable = bWarnOnUnusedVar;
	}
}

==> jena-5.5.0-source-release.zip: jena-5.5.0/jena-arq/src/test/java/org/apache/jena/sparql/function/user/TS_UserFunctions.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.sparql.function.user;

import org.junit.jupiter.api.AfterAll;
import org.junit.jupiter.api.BeforeAll;
import org.junit.platform.suite.api.SelectClasses;
import org.junit.platform.suite.api.Suite;

@Suite
@SelectClasses({

    TestUserDefinedFunctionFactory.class,
    TestFunctionExpansion.class,
    TestFunctionNonExpansion.class,
    TestUserFunctionsInSparql.class
})
public class TS_UserFunctions {

	//Expected warnings off
	private static boolean bWarnOnUnusedVar;

	@BeforeAll
	public static void setup() {
		bWarnOnUnusedVar = UserDefinedFunctionDefinition.warnOnUnusedVariable;
		UserDefinedFunctionDefinition.warnOnUnusedVariable = false;
	}

	@AfterAll
	public static void teardown() {
		UserDefinedFunctionDefinition.warnOnUnusedVariable = bWarnOnUnusedVar;
	}
}
